@@ -40,9 +40,20 @@ class MonitorIndicator : public QFrame
 
 public:
     explicit MonitorIndicator(QWidget *parent = 0);
+    ~MonitorIndicator() override;
 
-protected:
-    void resizeEvent(QResizeEvent *e);
+public Q_SLOTS:
+
+    virtual void setVisible(bool visible);
+
+private:
+    void updateGeometry();
+
+private:
+    QFrame *m_topLine;
+    QFrame *m_bottomLine;
+    QFrame *m_leftLine;
+    QFrame *m_rightLine;
 };
 
 } // namespace display
