@@ -80,7 +80,7 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
                              "/com/deepin/daemon/SystemInfo",
                              "org.freedesktop.DBus.Properties",
                              QDBusConnection::sessionBus());
-    QDBusMessage reply = Interface.call("Get", "com.deepin.daemon.SystemInfo", "CPUMaxMHz");
+    QDBusMessage reply = Interface.call("Get", "com.deepin.daemon.SystemInfo", "CurrentSpeed");
     QList<QVariant> outArgs = reply.arguments();
     double cpuMaxMhz = outArgs.at(0).value<QDBusVariant>().variant().toDouble();
     if (DSysInfo::cpuModelName().contains("Hz")) {
@@ -177,13 +177,27 @@ void SystemInfoWork::activate()
         version = QString("%1%2").arg(DSysInfo::minorVersion())
                                   .arg(DSysInfo::uosEditionName());
     } else if (DSysInfo::isDeepin()) {
-        version = QString("%1 (%2)").arg(DSysInfo::uosEditionName())
-                                  .arg(DSysInfo::minorVersion());
+        //获取政务授权、企业授权
+        QString authorizationProperty = "";
+        AuthorizationProperty type = static_cast<AuthorizationProperty>(getLicenseAuthorizationProperty());
+        if (AuthorizationProperty::Government == type) {
+            authorizationProperty = tr("For Government");
+        } else if (AuthorizationProperty::Enterprise == type) {
+            authorizationProperty = tr("For Enterprise");
+        }
+
+        if (authorizationProperty != "") {
+            version = QString("%1(%2)(%3)").arg(DSysInfo::uosEditionName())
+                                      .arg(authorizationProperty)
+                                      .arg(DSysInfo::minorVersion());
+        } else {
+            version = QString("%1 (%2)").arg(DSysInfo::uosEditionName())
+                                      .arg(DSysInfo::minorVersion());
+        }
     } else {
         version = QString("%1 %2").arg(DSysInfo::productVersion())
                                   .arg(DSysInfo::productTypeString());
     }
-
     m_model->setVersion(version);
     m_model->setType(QSysInfo::WordSize);
 
@@ -292,6 +306,7 @@ void SystemInfoWork::onBackgroundChanged()
 
 void SystemInfoWork::setBackground(const QString &path)
 {
+#ifndef DCC_DISABLE_GRUB_THEME
     Q_EMIT requestSetAutoHideDCC(false);
 
     QDBusPendingCall call = m_dbusGrubTheme->SetBackgroundSourceFile(path);
@@ -307,6 +322,7 @@ void SystemInfoWork::setBackground(const QString &path)
 
         w->deleteLater();
     });
+#endif
 }
 
 void SystemInfoWork::showActivatorDialog()
@@ -388,6 +404,21 @@ void SystemInfoWork::getLicenseState()
     qDebug() << "authorize result:" << reply;
     m_model->setLicenseState(reply);
 }
+
+unsigned int SystemInfoWork::getLicenseAuthorizationProperty()
+{
+    QDBusInterface licenseInfo("com.deepin.license",
+                               "/com/deepin/license/Info",
+                               "com.deepin.license.Info",
+                               QDBusConnection::systemBus());
+
+    if (!licenseInfo.isValid()) {
+        qDebug() << "com.deepin.license error ," << licenseInfo.lastError().name();
+        return 0;
+    }
+
+    return licenseInfo.property("AuthorizationProperty").value<unsigned int>();
+}
 #endif
 
 }
