@@ -56,9 +56,6 @@ enum UpdatesStatus {
     UpdateSucceeded,
     UpdateFailed,
     NeedRestart,
-    NoNetwork,
-    NoSpace,
-    DeependenciesBrokenError,
     WaitRecoveryBackup,
     RecoveryBackingup,
     RecoveryBackingSuccessed,
@@ -66,6 +63,15 @@ enum UpdatesStatus {
     NoAtive
 };
 
+enum UpdateErrorType {
+    NoError,
+    NoNetwork,
+    NoSpace,
+    DeependenciesBrokenError,
+    DpkgInterrupted,
+    UnKnown
+};
+
 enum ShowStatus {
     NoActive,
     IsSuccessed,
@@ -140,14 +146,13 @@ static inline QString formatCap(qulonglong cap, const int size = 1024)
     return QString::number(double(cap) / size / size / size / size, 'f', 2) + type[4];
 }
 
-static inline vector<double> getNumListFromStr(const QString& str)
+static inline vector<double> getNumListFromStr(const QString &str)
 {
     //筛选出字符串中的数字
     QRegExp rx("-?[1-9]\\d*\\.\\d*|0+.[0-9]+|-?0\\.\\d*[1-9]\\d*|-?\\d+");
     int pos = 0;
     vector<double> v;
-    while ((pos = rx.indexIn(str, pos)) != -1)
-    {
+    while ((pos = rx.indexIn(str, pos)) != -1) {
         pos += rx.matchedLength();
         v.push_back(rx.cap(0).toDouble());
     }
