@@ -73,6 +73,7 @@ UpdateModel::UpdateModel(QObject *parent)
     , m_autoCheckSecureUpdates(false)
     , m_autoCheckSystemUpdates(false)
     , m_autoCheckAppUpdates(false)
+    , m_autoCheckThirdpartyUpdates(false)
     , m_updateNotify(false)
     , m_smartMirrorSwitch(false)
     , m_mirrorId(QString())
@@ -341,9 +342,10 @@ void UpdateModel::setUpdateMode(quint64 updateMode)
 
     m_updateMode = updateMode;
 
-    setAutoCheckSystemUpdates(m_updateMode & 0b0001);
-    setAutoCheckAppUpdates((m_updateMode & 0b0010) >> 1);
-    setAutoCheckSecureUpdates((m_updateMode & 16) >> 4);
+    setAutoCheckSystemUpdates(m_updateMode & ClassifyUpdateType::SystemUpdate);
+    setAutoCheckAppUpdates(m_updateMode & ClassifyUpdateType::AppStoreUpdate);
+    setAutoCheckSecureUpdates(m_updateMode & ClassifyUpdateType::SecurityUpdate);
+    setAutoCheckThirdpartyUpdates(m_updateMode & ClassifyUpdateType::UnknownUpdate);
 }
 
 void UpdateModel::setAutoCheckSecureUpdates(bool autoCheckSecureUpdates)
@@ -651,23 +653,33 @@ void UpdateModel::setUnkonwUpdateJobError(const UpdateJobErrorMessage &UnkonwUpd
     m_UnkonwUpdateJobError = UnkonwUpdateJobError;
 }
 
-void UpdateModel::setClassityUpdateJonError(ClassifyUpdateType type, const UpdateJobErrorMessage &UnkonwUpdateJobError)
+void UpdateModel::setClassityUpdateJonError(ClassifyUpdateType type, UpdateErrorType errorType)
 {
-    switch (type) {
-    case ClassifyUpdateType::SystemUpdate:
-        setSystemUpdateJobError(UnkonwUpdateJobError);
-        break;
-    case ClassifyUpdateType::SecurityUpdate:
-        setSafeUpdateJobError(UnkonwUpdateJobError);
-        break;
-    case ClassifyUpdateType::UnknownUpdate:
-        setUnkonwUpdateJobError(UnkonwUpdateJobError);
-        break;
-    default:
-        break;
+    if (m_updateErrorTypeMap.contains(type)) {
+        m_updateErrorTypeMap.remove(type);
+    }
+    m_updateErrorTypeMap.insert(type, errorType);
+
+    Q_EMIT classityUpdateJobErrorChanged(type, errorType);
+}
+
+QMap<ClassifyUpdateType, UpdateErrorType> UpdateModel::getUpdateErrorTypeMap() const
+{
+    return m_updateErrorTypeMap;
+}
+
+bool UpdateModel::getAutoCheckThirdpartyUpdates() const
+{
+    return m_autoCheckThirdpartyUpdates;
+}
+
+void UpdateModel::setAutoCheckThirdpartyUpdates(bool autoCheckThirdpartyUpdates)
+{
+    if (m_autoCheckThirdpartyUpdates != autoCheckThirdpartyUpdates) {
+        m_autoCheckThirdpartyUpdates = autoCheckThirdpartyUpdates;
+        Q_EMIT autoCheckThirdpartyUpdatesChanged(m_autoCheckThirdpartyUpdates);
     }
 
-    Q_EMIT classityUpdateJobErrorChanged(type, UnkonwUpdateJobError.jobErrorMessage);
 }
 
 UpdatesStatus UpdateModel::getClassifyUpdateStatus(ClassifyUpdateType type)
