@@ -229,7 +229,12 @@ public:
     UpdateJobErrorMessage getUnkonwUpdateJobError() const;
     void setUnkonwUpdateJobError(const UpdateJobErrorMessage &UnkonwUpdateJobError);
 
-    void setClassityUpdateJonError(ClassifyUpdateType type, const UpdateJobErrorMessage &UnkonwUpdateJobError);
+    void setClassityUpdateJonError(ClassifyUpdateType type, UpdateErrorType errorType);
+
+    QMap<ClassifyUpdateType, UpdateErrorType> getUpdateErrorTypeMap() const;
+
+    bool getAutoCheckThirdpartyUpdates() const;
+    void setAutoCheckThirdpartyUpdates(bool autoCheckThirdpartyUpdates);
 
 Q_SIGNALS:
     void autoDownloadUpdatesChanged(const bool &autoDownloadUpdates);
@@ -261,7 +266,7 @@ Q_SIGNALS:
     void safeUpdateInfoChanged(UpdateItemInfo *updateItemInfo);
     void unknownUpdateInfoChanged(UpdateItemInfo *updateItemInfo);
 
-    void classityUpdateJobErrorChanged(ClassifyUpdateType type, const QString &errorMessage);
+    void classityUpdateJobErrorChanged(const ClassifyUpdateType &type, const UpdateErrorType &errorType);
 
     void systemUpdateProgressChanged(const double &updateProgress);
     void safeUpdateProgressChanged(const double &updateProgress);
@@ -275,6 +280,7 @@ Q_SIGNALS:
     void autoCheckSystemUpdatesChanged(const bool autoCheckSystemUpdate);
     void autoCheckAppUpdatesChanged(const bool autoCheckAppUpdate);
     void autoCheckSecureUpdatesChanged(const bool autoCheckSecureUpdate);
+    void autoCheckThirdpartyUpdatesChanged(const bool autoCheckThirdpartyUpdate);
     void recoverBackingUpChanged(bool recoverBackingUp);
     void recoverConfigValidChanged(bool recoverConfigValid);
     void recoverRestoringChanged(bool recoverRestoring);
@@ -318,6 +324,7 @@ private:
     bool m_autoCheckSecureUpdates;
     bool m_autoCheckSystemUpdates;
     bool m_autoCheckAppUpdates;
+    bool m_autoCheckThirdpartyUpdates;
     bool m_updateNotify;
     bool m_smartMirrorSwitch;
     QString m_mirrorId;
@@ -335,6 +342,8 @@ private:
     int m_autoCheckUpdateCircle; //决定进入检查更新界面是否自动检查,单位：小时
     bool m_isUpdatablePackages;
 
+    QMap<ClassifyUpdateType, UpdateErrorType> m_updateErrorTypeMap;
+
     UpdateJobErrorMessage m_systemUpdateJobError;
     UpdateJobErrorMessage m_safeUpdateJobError;
     UpdateJobErrorMessage m_UnkonwUpdateJobError;
