@@ -80,6 +80,7 @@ public:
 
     QString getReleaseNoteStatus() const;
     void setReleaseNoteStatus(const QString &releaseNoteStatus);
+    bool hasRepositoriesUpdates();
 
 Q_SIGNALS:
     void requestInit();
@@ -122,6 +123,8 @@ public Q_SLOTS:
     void OnDownloadJobCtrl(ClassifyUpdateType type, int updateCtrlType);
     void onRequestOpenAppStore();
     void onClassifiedUpdatablePackagesChanged(QMap<QString, QStringList> packages);
+    void onFixError(const ClassifyUpdateType &updateType, const QString &errorType);
+    void onRequestLastoreHeartBeat();
 
 private Q_SLOTS:
     void setCheckUpdatesJob(const QString &jobPath);
@@ -171,12 +174,15 @@ private:
     void deleteClassityInstallJob(ClassifyUpdateType type);
     bool checkUpdateSuccessed();
     void cleanLastoreJob(QPointer<JobInter> dbusJob);
-    UpdateJobErrorMessage analyzeJobErrorMessage(QString jobDescription);
+    UpdateErrorType analyzeJobErrorMessage(QString jobDescription);
     QString getClassityUpdateDownloadJobName(ClassifyUpdateType updateType);
+    void listenReleaseNoteFile();
+    void checkUpdatablePackages(const QMap<QString, QStringList> &updatablePackages);
 
 private:
     UpdateModel *m_model;
     QPointer<JobInter> m_checkUpdateJob;
+    QPointer<JobInter> m_fixErrorJob;
 
     QPointer<JobInter> m_sysUpdateDownloadJob;
     QPointer<JobInter> m_safeUpdateDownloadJob;
@@ -219,7 +225,10 @@ private:
     BackupStatus m_backupStatus;
     // 当前正在备份的更新分类类型
     ClassifyUpdateType m_backupingClassifyType;
-    QString m_releaseNoteStatus;
+    QString m_releaseNoteJobStatus;
+    bool m_releaseNoteUpdated;
+    QFileSystemWatcher *m_fileSystemWatcher;
+    QList<ClassifyUpdateType> m_fixErrorUpdate;
 
     QMutex m_mutex;
     QMutex m_downloadMutex;
