@@ -304,6 +304,7 @@ void MainWindow::setPrimaryScreen(QScreen *screen)
     m_primaryScreen = screen;
     updateWinsize();
     connect(m_primaryScreen, &QScreen::geometryChanged, this, &MainWindow::updateWinsize);
+    connect(m_primaryScreen, &QScreen::availableGeometryChanged, this, &MainWindow::updateWinsize);
 }
 
 void MainWindow::initAllModule(const QString &m)
@@ -1402,3 +1403,12 @@ QString MainWindow::moduleDisplayName(const QString &module) const
     }
     return find_it->second;
 }
+
+
+bool MainWindow::event(QEvent *event)
+{
+    if(event->type() == QEvent::Show || event->type() == QEvent::Hide ){
+        Q_EMIT mainwindowStateChange(event->type());
+    }
+    return DMainWindow::event(event);
+}
