@@ -11,6 +11,7 @@
 
 #include <QVector>
 #include <QWidget>
+#include <QPointer>
 
 namespace dcc {
 namespace authentication {
@@ -49,8 +50,8 @@ private:
     dcc::widgets::SettingsGroup *m_listGrp;
     DCommandLinkButton *m_clearBtn;
     QVector<AuthenticationInfoItem*> m_vecItem;
-    AuthenticationLinkButtonItem* m_addfaceItem;
-    DCommandLinkButton *m_addBtn;
+    QPointer<AuthenticationLinkButtonItem> m_addfaceItem;
+    QPointer<DCommandLinkButton> m_addBtn;
 };
 
 }
