@@ -30,6 +30,7 @@
 #include "widgets/settingsgroup.h"
 #include "widgets/titlelabel.h"
 #include "window/utils.h"
+#include "window/gsettingwatcher.h"
 
 #include <DListView>
 
@@ -52,16 +53,22 @@ DWIDGET_USE_NAMESPACE
 
 AdapterWidget::AdapterWidget(const dcc::bluetooth::Adapter *adapter, dcc::bluetooth::BluetoothModel *model)
     : m_titleEdit(new TitleEdit)
-    , m_hideAnonymousLabel(new QLabel(tr("Show Bluetooth devices without names")))
     , m_adapter(adapter)
     , m_powerSwitch(new SwitchWidget(nullptr, m_titleEdit))
     , m_showAnonymousCheckBox(new DCheckBox(this))
     , m_model(model)
-    , m_discoverySwitch(new SwitchWidget(tr("Allow other Bluetooth devices to find this device")))
-    , m_lastPowerCheck(false)
-    , m_bluetoothInter("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this)
 {
-    initMember();
+    setAccessibleName("AdapterWidget");
+    m_showAnonymousCheckBox->setAccessibleName("AnonymousCheckBox");
+
+    //~ contents_path /bluetooth/Show Bluetooth devices without names
+    m_hideAnonymousLabel = new QLabel(tr("Show Bluetooth devices without names"));
+    //~ contents_path /bluetooth/Allow other Bluetooth devices to find this device
+    m_discoverySwitch = new SwitchWidget(tr("Allow other Bluetooth devices to find this device"));
+    //~ contents_path /bluetooth/My Devices
+    m_myDevicesGroup = new TitleLabel(tr("My Devices"));
+    //~ contents_path /bluetooth/Other Devices
+    m_otherDevicesGroup = new TitleLabel(tr("Other Devices"));
     initUI();
     initConnect();
 
@@ -82,19 +89,30 @@ bool AdapterWidget::getSwitchState()
     return m_powerSwitch ? m_powerSwitch->checked() : false;
 }
 
-void AdapterWidget::initMember()
+void AdapterWidget::setMyDevicesVisible(bool visible)
 {
-    m_showUnnamedDevices = m_bluetoothInter.displaySwitch();
+    if (!m_myDevicesGroup) {
+        return;
+    }
+
+    m_myDevicesGroup->setVisible(visible);
+    m_model->setMyDeviceVisible(visible);
+}
+
+void AdapterWidget::setOtherDevicesVisible(bool visible)
+{
+    if (!m_otherDevicesGroup) {
+        return;
+    }
+
+    m_otherDevicesGroup->setVisible(visible);
+    m_model->setOtherDeviceVisible(visible);
 }
 
 void AdapterWidget::initUI()
 {
-    //~ contents_path /bluetooth/My Devices
-    m_myDevicesGroup = new TitleLabel(tr("My Devices"));
-    m_myDevicesGroup->setVisible(false);
+    setMyDevicesVisible(false);
 
-    //~ contents_path /bluetooth/Other Devices
-    m_otherDevicesGroup = new TitleLabel(tr("Other Devices"));
     m_spinnerBtn = new DSpinner(m_titleEdit);
 
     m_titleEdit->setMinimumWidth(10);
@@ -111,7 +129,14 @@ void AdapterWidget::initUI()
     m_refreshBtn = new DIconButton(this);
     m_refreshBtn->setFixedSize(36, 36);
     m_refreshBtn->setIcon(QIcon::fromTheme("dcc_refresh"));
-    m_showAnonymousCheckBox->setChecked(m_showUnnamedDevices);
+
+    QDBusInterface app_ifc("com.deepin.daemon.Bluetooth",
+                           "/com/deepin/daemon/Bluetooth",
+                           "com.deepin.daemon.Bluetooth",
+                           QDBusConnection::sessionBus()
+                );
+    bool Checked = app_ifc.property("DisplaySwitch").toBool();
+    m_showAnonymousCheckBox->setChecked(Checked);
     m_showAnonymousCheckBox->setAccessibleName("Btn_anonymouscheckbox");
 
     m_hideAnonymousLabel->setFixedHeight(36);
@@ -139,8 +164,8 @@ void AdapterWidget::initUI()
     settingsGrp->appendItem(m_powerSwitch);
     settingsGrp->appendItem(m_discoverySwitch);
 
+    //~ contents_path /bluetooth/Enable Bluetooth to find nearby devices (speakers, keyboard, mouse)
     m_tip = new QLabel(tr("Enable Bluetooth to find nearby devices (speakers, keyboard, mouse)"));
-    m_tip->setVisible(!m_powerSwitch->checked());
     m_tip->setWordWrap(true);
     m_tip->setContentsMargins(16, 0, 10, 0);
 
@@ -178,7 +203,6 @@ void AdapterWidget::initUI()
     layout->setMargin(0);
     layout->setSpacing(10);
 
-    layout->addSpacing(10);
     layout->addWidget(settingsGrp);
     layout->addWidget(m_tip, 0, Qt::AlignTop);
     layout->addSpacing(10);
@@ -191,7 +215,20 @@ void AdapterWidget::initUI()
     layout->addWidget(m_otherDeviceListView);
     layout->addSpacing(interval);
     layout->addStretch();
-    layout->setContentsMargins(ThirdPageContentsMargins);
+    layout->setContentsMargins(QMargins(10,0,10,10));
+
+    m_discoverySwitch->setVisible(false);
+    m_tip->setVisible(true);
+    setMyDevicesVisible(false);
+    setOtherDevicesVisible(false);
+    m_showAnonymousCheckBox->setVisible(false);
+    m_hideAnonymousLabel->setVisible(false);
+    m_spinner->setVisible(false);
+    m_refreshBtn->setVisible(false);
+    m_myDeviceListView->setVisible(false);
+    m_otherDeviceListView->setVisible(false);
+
+    setEnabled(!m_model->airplaneMode());
 
     setLayout(layout);
 }
@@ -264,14 +301,14 @@ void AdapterWidget::initConnect()
         Q_EMIT requestSetToggleAdapter(m_adapter, check);
     });
 
+    GSettingWatcher::instance()->bind("bluetoothSwitch", m_powerSwitch->switchButton());
+
     connect(m_discoverySwitch, &SwitchWidget::checkedChanged, this, &AdapterWidget::toggleDiscoverableSwitch);
 
-    connect(&m_bluetoothInter, &BluetoothInter::DisplaySwitchChanged, m_showAnonymousCheckBox, &DCheckBox::setChecked);
+    connect(m_model, &BluetoothModel::displaySwitchChanged, m_showAnonymousCheckBox, &DCheckBox::setChecked);
     connect(m_showAnonymousCheckBox, &DCheckBox::stateChanged, this, [ = ](int state) {
         if (state == Qt::CheckState::Unchecked) {
-            if (m_bluetoothInter.displaySwitch()) {
-                m_bluetoothInter.setDisplaySwitch(false);
-            }
+            Q_EMIT requestSetDisplaySwitch(false);
             // 将蓝牙名称为空的设备过滤掉
             for (int i = 0; i < m_deviceLists.size(); i++) {
                 DeviceSettingsItem *pDeviceItem = m_deviceLists[i];
@@ -288,9 +325,7 @@ void AdapterWidget::initConnect()
                 }
             }
         } else {
-            if (!m_bluetoothInter.displaySwitch()) {
-                m_bluetoothInter.setDisplaySwitch(true);
-            }
+            Q_EMIT requestSetDisplaySwitch(true);
             // 显示所有蓝牙设备
             for (int i = 0; i < m_deviceLists.size(); i++) {
                 DeviceSettingsItem *pDeviceItem = m_deviceLists[i];
@@ -307,6 +342,8 @@ void AdapterWidget::initConnect()
             }
         }
     });
+
+    connect(m_model, &BluetoothModel::airplaneEnableChanged, this, &AdapterWidget::setDisabled);
 }
 
 void AdapterWidget::loadDetailPage()
@@ -340,7 +377,6 @@ void AdapterWidget::setAdapter(const Adapter *adapter)
     connect(adapter, &Adapter::discoverableChanged, m_discoverySwitch, [ = ] {
         m_discoverySwitch->setChecked(adapter->discoverabled());
     });
-    m_lastPowerCheck = adapter->powered();
     m_discoverySwitch->setChecked(m_adapter->discoverabled());
     onPowerStatus(adapter->powered(), adapter->discovering());
 }
@@ -349,12 +385,12 @@ void AdapterWidget::onPowerStatus(bool bPower, bool bDiscovering)
 {
     m_powerSwitch->setEnabled(true);
     m_powerSwitch->setChecked(bPower);
+    m_powerSwitch->setVisible(true);
     m_discoverySwitch->setEnabled(true);
     m_discoverySwitch->setVisible(bPower);
     m_tip->setVisible(!bPower);
-    m_discoverySwitch->setVisible(bPower);
-    m_myDevicesGroup->setVisible(bPower && !m_myDevices.isEmpty());
-    m_otherDevicesGroup->setVisible(bPower);
+    setMyDevicesVisible(bPower && !m_myDevices.isEmpty());
+    setOtherDevicesVisible(bPower);
     m_showAnonymousCheckBox->setVisible(bPower);
     m_hideAnonymousLabel->setVisible(bPower);
     m_spinner->setVisible(bPower && bDiscovering);
@@ -376,7 +412,6 @@ void AdapterWidget::toggleSwitch(const bool checked)
             }
         }
     }
-    m_lastPowerCheck = checked;
     Q_EMIT requestSetToggleAdapter(m_adapter, checked);
 }
 
@@ -385,6 +420,21 @@ void AdapterWidget::toggleDiscoverableSwitch(const bool checked)
     Q_EMIT requestDiscoverable(m_adapter, checked);
 }
 
+// 刷新声音list状态
+void AdapterWidget::refreshAudioDeviceStatu(const Device::State &state, bool paired)
+{
+    QList<QPointer<DeviceSettingsItem>> allDevice;
+    allDevice.append(m_myDevices);
+    allDevice.append(m_deviceLists);
+
+    for (auto dev : allDevice) {
+        if (dev->device()->deviceType() == "pheadset") {
+            // 若是连接状态 暂时不可用
+            dev->getStandardItem()->setEnabled((state != Device::StateAvailable));
+        }
+    }
+}
+
 void AdapterWidget::categoryDevice(DeviceSettingsItem *deviceItem, const bool paired)
 {
     if (deviceItem) {
@@ -404,7 +454,7 @@ void AdapterWidget::categoryDevice(DeviceSettingsItem *deviceItem, const bool pa
         }
     }
     bool isVisible = !m_myDevices.isEmpty() && m_powerSwitch->checked();
-    m_myDevicesGroup->setVisible(isVisible);
+    setMyDevicesVisible(isVisible);
     m_myDeviceListView->setVisible(isVisible);
 }
 
@@ -412,6 +462,10 @@ void AdapterWidget::addDevice(const Device *device)
 {
     if (!device)
         return;
+    // 单独判断蓝牙音频设备
+    if (device->deviceType() == "pheadset")
+        connect(device, &Device::stateChanged, this, &AdapterWidget::refreshAudioDeviceStatu, Qt::UniqueConnection);
+
     QPointer<DeviceSettingsItem> deviceItem = new DeviceSettingsItem(device, style());
     categoryDevice(deviceItem, device->paired());
 
@@ -445,7 +499,7 @@ void AdapterWidget::addDevice(const Device *device)
             }
         }
         bool isVisible = !m_myDevices.isEmpty() && m_powerSwitch->checked();
-        m_myDevicesGroup->setVisible(isVisible);
+        setMyDevicesVisible(isVisible);
         m_myDeviceListView->setVisible(isVisible);
     });
     connect(deviceItem, &DeviceSettingsItem::requestShowDetail, this, [this](const Device * device) {
