@@ -51,16 +51,29 @@ DatetimeModule::DatetimeModule(FrameProxyInterface *frameProxy, QObject *parent)
     GSettingWatcher::instance()->insertState("timezoneList");
     GSettingWatcher::instance()->insertState("timeSettings");
     GSettingWatcher::instance()->insertState("timeFormat");
+
+    /*以下三行为默认程序模块服务，由于每个cpp只能有一种翻译，故将注释分配到其他地方*/
+    //~ contents_path /defapp/Picture/Add Application
+    //~ child_page Picture
+    tr("Add Application");
 }
 
-void DatetimeModule::initialize()
+void DatetimeModule::preInitialize(bool sync, FrameProxyInterface::PushType)
 {
+    Q_UNUSED(sync)
+
     m_work = &DatetimeWork::getInstance();
     m_model = m_work->model();
 
     m_work->moveToThread(qApp->thread());
     m_model->moveToThread(qApp->thread());
 
+    addChildPageTrans();
+    initSearchData();
+}
+
+void DatetimeModule::initialize()
+{
 #ifndef DCC_DISABLE_TIMEZONE
     connect(this, &DatetimeModule::requestSetTimeZone, m_work, &DatetimeWork::setTimezone);
     connect(this, &DatetimeModule::requestRemoveUserTimeZone, m_work, &DatetimeWork::removeUserTimeZone);
@@ -133,7 +146,7 @@ int DatetimeModule::load(const QString &path)
         type = TimeSetting;
     } else if (path == "Timezone List/Add Timezone") {
         type = AddTimeZone;
-    } else if (path == "Format Settings") {
+    } else if (path == "Time Format") {
         type = FormatSetting;
     }
 
@@ -182,11 +195,149 @@ int DatetimeModule::load(const QString &path)
 QStringList DatetimeModule::availPage() const
 {
     QStringList list;
-    list << "Timezone List" << "Timezone List/Change System Timezone" << "Time Settings" << "Timezone List/Add Timezone";
+    list << "Timezone List" << "Timezone List/Change System Timezone" << "Time Settings" << "Timezone List/Add Timezone" << "Time Format";
 
     return list;
 }
 
+void DatetimeModule::addChildPageTrans() const
+{
+    if (m_frameProxy != nullptr) {
+        //datetime
+        m_frameProxy->addChildPageTrans("Time Format", tr("Time Format"));
+        m_frameProxy->addChildPageTrans("Timezone List", tr("Timezone List"));
+        m_frameProxy->addChildPageTrans("Time Settings", tr("Time Settings"));
+    }
+}
+
+void DatetimeModule::initSearchData()
+{
+    static QMap<QString, bool> gsettingsMap;
+    const QString& module = displayName();
+    const QString& timeSettings = tr("Time Settings");
+    const QString& timezoneList = tr("Timezone List");
+    const QString& formatSettings = tr("Time Format");
+
+    const QStringList& gsecondList {
+        "timezoneList"
+        , "timeSettings"
+        , "timeFormat"
+    };
+
+    auto func_is_visible = [ = ](const QString &gsettings, bool state = false) {
+        if (gsettings == "") {
+            return false;
+        }
+
+        bool ret = false;
+        if (state) {
+            ret = GSettingWatcher::instance()->get(gsettings).toBool();
+        } else {
+            ret = GSettingWatcher::instance()->get(gsettings).toString() != "Hidden";
+        }
+
+        gsettingsMap.insert(gsettings, ret);
+        return ret;
+    };
+
+    auto func_timezonelist_changed = [ = ]() {
+        if (!m_frameProxy || !m_model) {
+            return;
+        }
+
+        bool bTimezonelist = func_is_visible("timezoneList", true);
+        m_frameProxy->setWidgetVisible(module, timezoneList, bTimezonelist);
+        m_frameProxy->setDetailVisible(module, timezoneList, tr("Change System Timezone"), bTimezonelist);
+        m_frameProxy->setDetailVisible(module, timezoneList, tr("System Timezone"), bTimezonelist);
+        m_frameProxy->setDetailVisible(module, timezoneList, tr("Add Timezone"), bTimezonelist && func_is_visible("datetimeZonelistAddtimezone"));
+    };
+
+    auto func_format_changed = [ = ]() {
+        if (!m_frameProxy || !m_model) {
+            return;
+        }
+
+        //TODO: datetimeFromatsetting为Hidden时只会隐藏三级页面，耳机页面的选项还在需要移除
+        bool bTimeFormat = func_is_visible("timeFormat", true) && func_is_visible("datetimeFromatsetting");
+        m_frameProxy->setWidgetVisible(module, formatSettings, bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Date and Time Formats"), bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Weeks").remove('/'), bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Short Date"), bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Long Date"), bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Short Time"), bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Long Time"), bTimeFormat);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("First Day of Week"), bTimeFormat);
+    };
+
+    auto func_setting_changed = [ = ]() {
+        if (!m_frameProxy || !m_model) {
+            return;
+        }
+
+        bool bTimeSettings = func_is_visible("timeSettings", true);
+        m_frameProxy->setWidgetVisible(module, timeSettings, bTimeSettings);
+        m_frameProxy->setDetailVisible(module, timeSettings, tr("Auto Sync"), bTimeSettings && func_is_visible("datetimeDatesettingAutosync"));
+        m_frameProxy->setDetailVisible(module, timeSettings, tr("Server"), bTimeSettings && m_model->nTP());
+    };
+
+    auto func_process_all = [ = ]() {
+        m_frameProxy->setWidgetVisible(module, tr("24-hour Time"), true);
+
+        func_timezonelist_changed();
+
+        func_format_changed();
+
+        func_setting_changed();
+     };
+
+    //更新开/关时间同步显示“服务器”
+    connect(m_model, &DatetimeModel::NTPChanged, [ = ](bool value) {
+        m_frameProxy->setDetailVisible(module, timeSettings, tr("Server"), func_is_visible("timeSettings", true) && value);
+        if (m_frameProxy) {
+            m_frameProxy->updateSearchData(module);
+        }
+    });
+
+    //gsetting data changed
+    connect(GSettingWatcher::instance(), &GSettingWatcher::notifyGSettingsChanged, this, [=](const QString &gsetting, const QString &state) {
+        if ("" == gsetting || !gsettingsMap.contains(gsetting)) {
+            return;
+        }
+
+        if (gsecondList.contains(gsetting)) {//bool: timezonlist, timeFormat, timeSettings
+            if (gsettingsMap.value(gsetting) == GSettingWatcher::instance()->get(gsetting).toBool()) {
+                return;
+            }
+        } else {//QString: datetimeZonelistAddtimezone, datetimeDatesettingAutosync, datetimeFromatsetting
+            if (gsettingsMap.value(gsetting) == (state != "Hidden")) {
+                return;
+            }
+        }
+
+        if ("timezoneList" == gsetting) {
+            func_timezonelist_changed();
+        } else if ("timeSettings" == gsetting) {
+            func_setting_changed();
+        } else if ("timeFormat" == gsetting || "datetimeFromatsetting" == gsetting) {
+            func_format_changed();
+        } else if ("datetimeZonelistAddtimezone" == gsetting) {
+            if (m_frameProxy)
+                m_frameProxy->setDetailVisible(module, timezoneList, tr("Add Timezone"), func_is_visible("timezoneList") && func_is_visible("datetimeZonelistAddtimezone"));
+        } else if ("datetimeDatesettingAutosync" == gsetting) {
+            if (m_frameProxy)
+                m_frameProxy->setDetailVisible(module, timeSettings, tr("Auto Sync"), func_is_visible("timeSettings", true) && func_is_visible("datetimeDatesettingAutosync"));
+        } else {
+            qWarning() << " not contains the gsettings : " << gsetting << state;
+            return;
+        }
+
+        qInfo() << " [notifyGSettingsChanged]  gsetting, state :" << gsetting << state;
+        m_frameProxy->updateSearchData(module);
+    });
+
+    func_process_all();
+}
+
 void DatetimeModule::updateSystemTimezone(const QString &timezone)
 {
     if (timezone.isEmpty()) return;
@@ -213,7 +364,7 @@ void DatetimeModule::ensureZoneChooserDialog()
     if (m_dialog)
         return;
 
-    m_dialog = new TimeZoneChooser();
+    m_dialog = new TimeZoneChooser(m_pMainWindow);
     m_dialog->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(m_dialog, &TimeZoneChooser::confirmed, this, [this](const QString & timezone) {
@@ -277,6 +428,7 @@ void DatetimeModule::showTimezoneList()
     }
 
     QWidget *widget = new QWidget;
+    widget->setAccessibleName("TimezoneList");
     widget->setVisible(false);
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setMargin(0);
@@ -353,6 +505,7 @@ void DatetimeModule::onPopWidget()
     QModelIndex index = list->model()->index(ETimezoneList, 0);
     list->setCurrentIndex(index);
     list->clicked(index);
+    m_widget->setFocus();
 }
 
 void DatetimeModule::closeDialog()
