@@ -146,6 +146,18 @@ void DisplayModule::preInitialize(bool sync, FrameProxyInterface::PushType pusht
         }
     });
 
+    // 在wayland环境下，仅单屏切换的时候，会出现display服务告知主屏已变化，但是Qt的屏幕信息还没有准备好的情况
+    // 此处监听一下屏幕增加的信号，然后重新获取数据设置一下主屏（如果之前主屏已经设置了，此时设置并不会有影响）
+    connect(qApp, &QApplication::screenAdded, this, [this] {
+        if (m_pMainWindow && QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+            for (auto mon : m_displayModel->monitorList()) {
+                if (mon->isPrimary()) {
+                    m_pMainWindow->setPrimaryScreen(mon->getQScreen());
+                }
+            }
+        }
+    });
+
     connect(m_displayModel, &DisplayModel::primaryScreenChanged, this, [=] (QString primary) {
         if (m_pMainWindow && !primary.isEmpty()) {
             for (auto mon : m_displayModel->monitorList()) {
@@ -284,7 +296,12 @@ void DisplayModule::showMultiScreenWidget()
         windowUpdate();
     });
 
-    MultiScreenWidget *multiScreenWidget = new MultiScreenWidget(m_pMainWindow);
+    MultiScreenWidget *multiScreenWidget = new MultiScreenWidget();
+    //wayland情况下这里设置父窗口会影响窗口最大化/还原的问题，详见bug 125867
+    if(!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)){
+        multiScreenWidget->setParent(m_pMainWindow);
+    }
+
     multiScreenWidget->setModel(m_displayModel);
     connect(multiScreenWidget, &MultiScreenWidget::requestSwitchMode, m_displayWorker, &DisplayWorker::switchMode);
     connect(multiScreenWidget, &MultiScreenWidget::requestSetMonitorPosition, m_displayWorker, &DisplayWorker::setMonitorPosition);
@@ -308,6 +325,9 @@ void DisplayModule::showMultiScreenWidget()
                 m_displayWorker->setCurrentFillMode(m, currfillMode);
         }
     });
+    if(QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)){
+        connect(m_pMainWindow, &MainWindow::mainwindowStateChange, multiScreenWidget, &MultiScreenWidget::onMainwindowStateChanged);
+    }
 
     connect(multiScreenWidget, &MultiScreenWidget::requestSetRotate, this, &DisplayModule::onRequestSetRotate, Qt::QueuedConnection);
     connect(multiScreenWidget, &MultiScreenWidget::requestSetMainwindowRect, this, [=](Monitor *moi,  bool isInit) {
