@@ -69,7 +69,7 @@ void KeyboardModule::preInitialize(bool sync, FrameProxyInterface::PushType)
         delete m_model;
     }
     m_model = new KeyboardModel();
-    m_shortcutModel = new ShortcutModel();
+    m_shortcutModel = new ShortcutModel(this);
     m_work = new KeyboardWorker(m_model);
 
     addChildPageTrans();
@@ -324,6 +324,7 @@ void KeyboardModule::onPushKeyboard(const QStringList &kblist)
 
     m_frameProxy->pushWidget(this, m_kbLayoutWidget);
     m_kbLayoutWidget->setVisible(true);
+    m_kbLayoutWidget->setFocus();
 }
 
 void KeyboardModule::setCurrentLayout(const QString &value)
@@ -386,7 +387,6 @@ void KeyboardModule::showShortCutSetting()
 
     if (QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
         connect(m_work, &KeyboardWorker::stareGrab, m_shortcutSettingWidget, &ShortCutSettingWidget::onGrab);
-        connect(m_shortcutSettingWidget, &ShortCutSettingWidget::changed, m_work, &KeyboardWorker::onShortcutChanged);
     }
 
     m_frameProxy->pushWidget(this, m_shortcutSettingWidget);
@@ -424,6 +424,7 @@ void KeyboardModule::onPushCustomShortcut()
 
     m_frameProxy->pushWidget(this, m_customContent);
     m_customContent->setVisible(true);
+    m_customContent->setFocus();
 }
 
 void KeyboardModule::onPushConflict(ShortcutInfo *info, const QString &shortcut)
@@ -435,9 +436,13 @@ void KeyboardModule::onPushConflict(ShortcutInfo *info, const QString &shortcut)
     connect(m_scContent, &ShortcutContent::requestUpdateKey, m_work, &KeyboardWorker::updateKey);
     connect(m_scContent, &ShortcutContent::requestDisableShortcut, m_work, &KeyboardWorker::onDisableShortcut);
     connect(m_scContent, &ShortcutContent::back, this, &KeyboardModule::showShortCutSetting);
+    if (QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+        connect(m_work, &KeyboardWorker::stareGrab, m_scContent, &ShortcutContent::onGrab);
+    }
 
     m_scContent->setInfo(info);
     m_scContent->setShortcut(shortcut);
+    m_scContent->setConflictShortcut(shortcut);
     m_scContent->setBottomTip(m_shortcutModel->getInfo(shortcut));
 
     m_frameProxy->pushWidget(this, m_scContent);
