@@ -56,6 +56,7 @@ UpdateWidget::UpdateWidget(QWidget *parent)
     , m_recentHistoryApplist(new RecentHistoryApplist)
     , m_topSwitchWidgetBtn(new DButtonBox)
     , m_mainLayout(new QStackedLayout)
+    , m_lastoreHeartBeatTimer(new QTimer)
 {
     DButtonBoxButton *btnUpdate = new DButtonBoxButton(QIcon::fromTheme("dcc_update_topupdate"), tr("Check for Updates"));
     btnUpdate->setIconSize(QSize(24, 24));
@@ -107,14 +108,27 @@ UpdateWidget::UpdateWidget(QWidget *parent)
     m_recentHistoryApplist->setContentWidget(m_applistGroup);
 
     m_layout->addWidget(m_recentHistoryApplist);
-
     setLayout(m_layout);
+
+    m_lastoreHeartBeatTimer->setInterval(60000);
+    m_lastoreHeartBeatTimer->start();
+    connect(m_lastoreHeartBeatTimer, &QTimer::timeout, this, &UpdateWidget::requestLastoreHeartBeat);
+
+    setFocusPolicy(Qt::FocusPolicy::ClickFocus);
 }
 
 UpdateWidget::~UpdateWidget()
 {
     delete  m_centerLayout;
     m_centerLayout = nullptr;
+
+    if (m_lastoreHeartBeatTimer != nullptr) {
+        if (m_lastoreHeartBeatTimer->isActive()) {
+            m_lastoreHeartBeatTimer->stop();
+        }
+        delete m_lastoreHeartBeatTimer;
+        m_lastoreHeartBeatTimer = nullptr;
+    }
 }
 
 void UpdateWidget::initialize()
@@ -147,6 +161,8 @@ void UpdateWidget::setModel(const UpdateModel *model, const UpdateWorker *work)
     connect(updateWidget, &UpdateCtrlWidget::requestUpdates, m_work, &UpdateWorker::distUpgrade);
     connect(updateWidget, &UpdateCtrlWidget::requestUpdateCtrl, m_work, &UpdateWorker::OnDownloadJobCtrl);
     connect(updateWidget, &UpdateCtrlWidget::requestOpenAppStroe, m_work, &UpdateWorker::onRequestOpenAppStore);
+    connect(this, &UpdateWidget::showUpdateCtrl, updateWidget, &UpdateCtrlWidget::onShowUpdateCtrl);
+    connect(updateWidget, &UpdateCtrlWidget::requestFixError, m_work, &UpdateWorker::onFixError);
     updateWidget->setSystemVersion(m_systemVersion);
 
     UpdateSettings *updateSetting = new UpdateSettings(m_model);
@@ -161,7 +177,7 @@ void UpdateWidget::setModel(const UpdateModel *model, const UpdateWorker *work)
 #ifndef DISABLE_SYS_UPDATE_SOURCE_CHECK
     connect(updateSetting, &UpdateSettings::requestSetSourceCheck, m_work, &UpdateWorker::setSourceCheck);
 #endif
-    if(IsCommunitySystem){
+    if (IsCommunitySystem) {
         connect(updateSetting, &UpdateSettings::requestEnableSmartMirror, m_work, &UpdateWorker::setSmartMirror);
     }
 
@@ -214,6 +230,7 @@ void UpdateWidget::showCheckUpdate()
         m_label->setVisible(true);
     }
     m_mainLayout->setCurrentIndex(0);
+    Q_EMIT showUpdateCtrl();
     // prohibit dde-offline-upgrader from showing while this page is showing.
     QDBusConnection::sessionBus().registerService(OfflineUpgraderService);
 }
@@ -281,9 +298,6 @@ void UpdateWidget::onNotifyUpdateState(int state)
     case Downloaded:
     case Installing:
     case UpdateFailed:
-    case NoNetwork:
-    case NoSpace:
-    case DeependenciesBrokenError:
         //now donothing
         break;
     default:
