@@ -299,7 +299,7 @@
     <message>
         <location filename="language.h" line="90"/>
         <source>कश्मीरी - (كشميري)</source>
-        <translation type="unfinished"/>
+        <translation>कश्मीरी - (Cachemire)</translation>
     </message>
     <message>
         <location filename="language.h" line="91"/>
